@@ -143,7 +143,7 @@ enum CommandFrame {
 pub struct Options<'a> {
     environment: HashMap<&'a str, &'a str>,
     tki: Option<Duration>,
-    input_data: Option<&'static [u8]>,
+    input_data: Option<std::borrow::Cow<'a, Vec<u8>>>,
 }
 
 impl<'a> Options<'a> {
@@ -157,7 +157,7 @@ impl<'a> Options<'a> {
         self
     }
     #[inline]
-    pub fn input(mut self, data: &'static [u8]) -> Self {
+    pub fn input(mut self, data: std::borrow::Cow<'a, Vec<u8>>) -> Self {
         self.input_data.replace(data);
         self
     }
@@ -260,8 +260,9 @@ where
         })
     });
     let fut_stdin = stdin_writer.map(|mut writer| {
+        let input_data = opts.input_data.unwrap().into_owned();
         task::spawn(async move {
-            if let Err(e) = writer.write_all(opts.input_data.unwrap()).await {
+            if let Err(e) = writer.write_all(&input_data).await {
                 error!("Unable to write to stdin: {}", e);
             } else if let Err(e) = writer.flush().await {
                 error!("Unable to flush stdin: {}", e);
